from pyspark.sql import *
from pyspark.sql.functions import *

class VantageCareSettings:
  def __init__(self, mountedJsonFileLocation):
    self.mountedFileLocation = mountedJsonFileLocation
    
  ###################################################### 
  # Get VC app setting by name, returns None if setting does not exist
  ###################################################### 
  def getSetting(self, nameOfSetting):
    # DISCLAIMER: Spark 2.3+ considers each newline character to be another json file. Make sure your json file is saved as a minified file before reading it by spark or use the option: multiline to parse the full json file
    # read json file into dataframe
    eventConfigJsonDf = spark.read.option("multiline","true").json(self.mountedFileLocation)
    dfSetting = None

    # this will only work if we have a schema that is NOT nested
    if nameOfSetting.upper() in (name.upper() for name in eventConfigJsonDf.columns):
      dfSetting = eventConfigJsonDf.select(first(nameOfSetting))
      return dfSetting.collect()[0][0]
    return None
   


from setuptools import setup, find_packages

# Utility function to read the README file.
# Used for the long_description.  It's nice, because now 1) we have a top level
# README file and 2) it's easier to type in the README file than to put a raw
# string in below ...
def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "azuredatabricksjsonsettings",
    version = "0.0.1",
    author = "Matt Meyer",
    author_email = "matt.meyer3@gmail.com",
    description = ("Azure Databricks Settings App with retrieval from JSON DBFS file"),
    long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
    license = "MIT",
    keywords = "calculator",
    url = " ",
    packages=find_packages(),
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
    ],
)